ananke.identification package
=============================

Submodules
----------

ananke.identification.missing\_id module
----------------------------------------

.. automodule:: ananke.identification.missing_id
   :members:
   :undoc-members:
   :show-inheritance:

ananke.identification.one\_line module
--------------------------------------

.. automodule:: ananke.identification.one_line
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ananke.identification
   :members:
   :undoc-members:
   :show-inheritance:
